import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.0
import "ucountDB.js" as UCountDB
import "Defines.js" as Defines

Page
{
    id: categoriesAddEditPage
    orientationLock: PageOrientation.LockPortrait
    property int categoryID: 0
    property int secondColumnWidth: 385
    property int iconID:0

    PageTitle
    {
        id: pageTitle
        title: "New Category"
        btnDoneVisible: true
        btnCancelVisible: true
        onCancelled:  pageStack.pop()
        onDone: saveCategory()
    }

    Grid
    {
        id: gridCategories
        columns: 2
        spacing: 2
        anchors.top: pageTitle.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        anchors.leftMargin: Defines.gridLeftMargin
        anchors.topMargin: Defines.gridTopMargin
        Text
        {
            id: lblName
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Name")
            anchors.verticalCenter: txtName.verticalCenter
        }
        TextField
        {
            id: txtName
            width: secondColumnWidth
        }
        Text
        {
            id: lblDescription
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Note")
            anchors.verticalCenter: txtDescription.verticalCenter
        }
        TextField
        {
            id: txtDescription
            width: secondColumnWidth
        }
        Text
        {
            id: lblIcon
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Icon")
            anchors.verticalCenter: btnIcon.verticalCenter
        }
        TumblerButton
        {
            id: btnIcon
            text: " "
            width: secondColumnWidth
            onClicked: iconsDialog.open()
        }
    }
    SelectionDialog
    {
        id: iconsDialog
        titleText: "Icons available"
        selectedIndex: 0
        onAccepted:
        {
            iconID=model.get(selectedIndex).tableID
            btnIcon.text= model.get(selectedIndex).name
        }
        model: ListModel
        {
            id: iconsModel
            ListElement
            {
                name: ""
                tableID: 0
            }
        }
    }
    function saveCategory()
    {
        UCountDB.saveCategory(categoryID, 0,  txtName.text,txtDescription.text, iconID)
        pageStack.pop()
    }

    function getCategory()
    {
        iconsModel.clear()
        var listIcons=UCountDB.readIcons()
        for(var vIcon in listIcons)iconsModel.append({"name":listIcons[vIcon].name,"tableID":listIcons[vIcon].id})
        if(categoryID==0)return
        UCountDB.getCategory(categoryID, function(infoCategory)
        {
            txtName.text=infoCategory.name
            txtDescription.text=infoCategory.description
            iconID=infoCategory.iconid
             UCountDB.getIcon(infoCategory.iconid, function(infoIcon)
             {
                 btnIcon.text=infoIcon.name
             });
        });
    }
    Component.onCompleted:  getCategory()
}
