import QtQuick 1.1
import com.nokia.meego 1.0
import "ucountDB.js" as UCountDB
import "Defines.js" as Defines

Page
{
    id: expensesPage
    tools: expensesTools
    property int sortType: UCountDB.SortType.lastMonth
    orientationLock: PageOrientation.LockPortrait
    property int listItemID:0
    UCountList
    {
        id: ucountList
        title: "Expenses"
        onListItemClicked:
        {
            var page=UCountDB.getPage(UCountDB.PageType.expensesAddEdit)
            pageStack.push(page,{expenseID: id})
        }
        onListItemPressAndHold:
        {
            listItemID=id
            menuLongPress.open()
        }
    }

    ToolBarLayout
    {
        id: expensesTools
        visible: true
        ToolIcon
        {
            id: toolBack
            platformIconId: "toolbar-back"
            anchors.left: parent.left
            onClicked:
            {
                if(myMenu.status === DialogStatus.Open) myMenu.close()
                pageStack.pop();
            }
        }
        ToolButton
        {
            id: toolPeriod
            anchors.horizontalCenter: expensesTools.horizontalCenter
            text: "Current month"
            onClicked:  (myMenu.status == DialogStatus.Closed) ? myMenu.open() : myMenu.close()
        }
        ToolIcon
        {
            id: toolAdd
            platformIconId: "toolbar-add"
            anchors.right: parent.right
            onClicked:
            {
                var page=UCountDB.getPage(UCountDB.PageType.expensesAddEdit)
                pageStack.push(page)
            }
        }
    }
    Menu
    {
        id: myMenu
        visualParent: pageStack
        MenuLayout
        {
            MenuItem
            {
                id: menuToday
                text: qsTr("Current day")
                onClicked:
                {
                    toolPeriod.text=qsTr("Current day")
                    sortType=UCountDB.SortType.today
                    init(PageStatus.Active)
                }
            }
            MenuItem
            {
                id: menuMonth
                text: qsTr("Current month")
                onClicked:
                {
                    toolPeriod.text=qsTr("Current month")
                    sortType=UCountDB.SortType.lastMonth
                    init(PageStatus.Active)
                }
            }
            MenuItem
            {
                id: menuYear
                text: qsTr("Current year")
                onClicked:
                {
                    toolPeriod.text=qsTr("Current year")
                    sortType=UCountDB.SortType.lastYear
                    init(PageStatus.Active)
                }
            }
            MenuItem
            {
                id: menuAll
                text: qsTr("Until today")
                onClicked:
                {
                    toolPeriod.text=qsTr("Until today")
                    sortType=UCountDB.SortType.all
                    init(PageStatus.Active)
                }
            }
            MenuItem
            {
                id: menuOneAhead
                text: qsTr("Until next year")
                onClicked:
                {
                    toolPeriod.text=qsTr("Until next year")
                    sortType=UCountDB.SortType.oneAhead
                    init(PageStatus.Active)
                }
            }
        }
    }
	Menu
    {
        id: menuLongPress
        visualParent: pageStack
        MenuLayout
        {
            MenuItem
            {
                id: menuDelete
                text: qsTr("Delete")
				onClicked: 
				{
                    UCountDB.deleteExpense(listItemID)
                    init(PageStatus.Active)
				}				
            }			
        }
    }	
    function init(status)
    {
        if(status!==PageStatus.Active)return
        ucountList.listModel.clear()
        var list=UCountDB.readExpenses(UCountDB.currentAccountID,sortType)
        var expenseSum=0
        var i=0        
        for(var v in list)
        {
            expenseSum+=list[v].value
            var categoryName
            var iconImage
            UCountDB.getCategory(list[v].categoryid, function(infoCategory)
            {
                 if((!infoCategory) || infoCategory.iconid===0)
                 {
                     iconImage="qrc:/Images/unknownexpense.png"
                     categoryName=""
                 }
                 else
                 {
                    categoryName=infoCategory.name
                     UCountDB.getIcon(infoCategory.iconid, function(infoIcon)
                     {
                         iconImage="qrc:/Images/"+infoIcon.qrcpath
                     });
                 }
            });
            var date= new Date(list[v].dateinserted)                              
            ucountList.listModel.append({"title":list[v].name,
                                            "subtitle":list[v].description,
                                            "value":list[v].value,
                                            "image":iconImage,
                                            "tableID":list[v].id,
                                            "category":categoryName,
                                            "dateInserted": Qt.formatDate(date,Qt.DefaultLocaleShortDate),
                                            "showDate":true,
                                            "transactionColor":"red"})
            i++
        }
        ucountList.pageInfo.showProgress(0,expenseSum,0)
    }
    onStatusChanged: init(status)
}
