import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.0
import "ucountDB.js" as UCountDB
import "Defines.js" as Defines

Page
{
    id: expensesAddEditPage
    orientationLock: PageOrientation.LockPortrait
    property int expenseID: 0
    property int secondColumnWidth: 360
    property int categoryID:0
    property int vendorID:0
    property int repeatID:1
    property date transactionDate:new Date()

    PageTitle
    {
        id: pageTitle
        title: "New Expense"
        btnDoneVisible: true
        btnCancelVisible: true
        onCancelled:  pageStack.pop()
        onDone: saveExpense()
    }

    Grid
    {
        id: grid
        columns: 2
        spacing: 2
        anchors.top: pageTitle.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        anchors.leftMargin: Defines.gridLeftMargin
        anchors.topMargin: UCountDB.gridTopMargin
        Text
        {
            id: lblValue
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Value")
            anchors.verticalCenter: txtValue.verticalCenter
        }
        TextField
        {
            id: txtValue
            validator: DoubleValidator{}
            width: secondColumnWidth
            inputMethodHints: Qt.ImhDigitsOnly | Qt.ImhNoPredictiveText
        }
        Text
        {
            id: lblName
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Name")
            anchors.verticalCenter: txtName.verticalCenter
        }
        TextField
        {
            id: txtName
            width: secondColumnWidth
        }
        Text
        {
            id: lblDescription
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Note")
            anchors.verticalCenter: txtDescription.verticalCenter
        }
        TextField
        {
            id: txtDescription
            width: secondColumnWidth
        }
        Text
        {
            id: lblDate
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Date")
            anchors.verticalCenter: btnDate.verticalCenter
        }
        TumblerButton
        {
            id: btnDate
            text:Qt.formatDate(transactionDate,Qt.DefaultLocaleShortDate)
            width: secondColumnWidth
            onClicked: launchDate()
        }
        Text
        {
            id: lblVendor
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Vendor")
            anchors.verticalCenter: btnVendor.verticalCenter
        }
        TumblerButton
        {
            id: btnVendor
            text: " "
            onClicked:
            {
                vendorDialog.open()
            }
            width: secondColumnWidth
        }
        Text
        {
            id: lblCategory
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Category")
            anchors.verticalCenter: btnCategory.verticalCenter
        }
        TumblerButton
        {
            id: btnCategory
            text: " "
            onClicked: categoryDialog.open()
            width: secondColumnWidth
        }
        Text
        {
            id: labelRepeat
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Repeat")
            anchors.verticalCenter: btnRepeat.verticalCenter
        }
        TumblerButton
        {
            id: btnRepeat
            text: "Once"
            onClicked: repeatDialog.open()
            width: secondColumnWidth
        }
    }
    SelectionDialog
    {
        id: repeatDialog
        titleText: "Repeat frequency"
        selectedIndex: 0
        onAccepted:
        {
            repeatID=model.get(selectedIndex).tableID
            btnRepeat.text= model.get(selectedIndex).name
        }
        model: ListModel
        {
        ListElement { name: "Once"; tableID:1}
        ListElement { name: "Every day";tableID:2 }
        ListElement { name: "Every week";tableID:3 }
        ListElement { name: "Every month";tableID:4 }
        ListElement { name: "Every year";tableID:5 }
        }
    }
    SelectionDialog
    {
        id: categoryDialog
        titleText: "Categories available"
        selectedIndex: 0
        onAccepted:
        {
            btnCategory.text= model.get(selectedIndex).name
            categoryID=model.get(selectedIndex).tableID
        }
        model: ListModel
        {
            id: categoryModel
            ListElement
            {
                name: ""
                tableID: 0
            }
        }
    }

    SelectionDialog
    {
        id: vendorDialog
        titleText: "Vendors available"
        selectedIndex: 0
        onAccepted:
        {
            vendorID=model.get(selectedIndex).tableID
            btnVendor.text= model.get(selectedIndex).name
            UCountDB.getVendor(vendorID, function(infoVendor)
            {
                categoryID=infoVendor.categoryid
                UCountDB.getCategory(categoryID,function(infoCategory)
                {
                    categoryID=infoCategory.id
                    btnCategory.text=infoCategory.name
                });
            });
        }
        model: ListModel
        {
            id: vendorsModel
            ListElement
            {
                name: ""
                tableID: 0
            }
        }
    }
    DatePickerDialog
    {
         id: dateDialog
         titleText: "Date of expense"
        minimumYear: 2005
         onAccepted: dateCallback()
     }
    ErrorDialog
    {
        id: errorDialog
    }

    function launchDate()
    {
         dateDialog.year = transactionDate.getFullYear();
         dateDialog.month = transactionDate.getMonth()+1;
         dateDialog.day = transactionDate.getDate();
         dateDialog.open();
     }
    function dateCallback()
    {
        transactionDate=Defines.getDateFromDatePickerDialog(dateDialog.year,dateDialog.month,dateDialog.day)
        btnDate.text=Qt.formatDate(transactionDate,Qt.DefaultLocaleShortDate)
    }

    function saveExpense()
    {
        if(txtValue.text.length<1)
        {
            errorDialog.text="Set a value"
            errorDialog.open()
            return
        }
        if(txtName.text.length<1)
        {
            errorDialog.text="Set a name"
            errorDialog.open()
            return
        }
        UCountDB.saveExpense(expenseID,UCountDB.currentAccountID, txtName.text, txtDescription.text, transactionDate, txtValue.text, categoryID,vendorID,0,repeatID)
        pageStack.pop()
    }    
    function getExpense()
    {
        vendorsModel.clear()
        var list=UCountDB.readVendors()
        for(var v in list)vendorsModel.append({"name":list[v].name,"tableID":list[v].id})
        categoryModel.clear()
        var listCategories=UCountDB.readTopLevelCategories()
        for(var vCategory in listCategories)categoryModel.append({"name":listCategories[vCategory].name,"tableID":listCategories[vCategory].id})
        if(expenseID==0)return
        UCountDB.getExpense(expenseID, function(info)
        {
            pageTitle.title="Edit Expense"
            txtValue.text=info.value
            txtName.text=info.name
            txtDescription.text=info.description
            repeatID=info.repeat
            btnRepeat.text=UCountDB.getRepeatName(repeatID)
            transactionDate= new Date(info.dateinserted)
            btnDate.text=Qt.formatDate(transactionDate,Qt.DefaultLocaleShortDate)
            UCountDB.getCategory(info.categoryid,function(infoCategory)
            {
                 if(!infoCategory)
                 {
                     categoryID=0
                     btnCategory.text=" "
                 }else
                  {
                    categoryID=infoCategory.id
                    btnCategory.text=infoCategory.name
                   }
            });
            UCountDB.getVendor(info.vendorid,function(info3)
            {
                vendorID=info3.id
                btnVendor.text=info3.name
            });
        });
    }
    Component.onCompleted:  getExpense()
}
