import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.0
import "ucountDB.js" as UCountDB
import "Defines.js" as Defines

Page
{
    id: historyPage
    tools: historyTools
    orientationLock: PageOrientation.LockPortrait
    property int sortType: UCountDB.SortType.lastMonth    
    property int listItemID:0
    property int listItemTransactionType:0
    UCountList
    {
        id: ucountList
        title: "History"
        onListItemClicked:
        {
            switch(transactionType)
            {
                case Defines.TransactionType.expense:
                    var page=UCountDB.getPage(UCountDB.PageType.expensesAddEdit)
                    pageStack.push(page,{expenseID: id})
                    break;
                case Defines.TransactionType.budget:
                    var pageB=UCountDB.getPage(UCountDB.PageType.budgetsAddEdit)
                    pageStack.push(pageB,{budgetID: id})
                    break;
            }
        }
        onListItemPressAndHold:
        {
            listItemID=id
            listItemTransactionType=transactionType
            menuLongPress.open()
        }
    }

    ToolBarLayout
    {
        id: historyTools
        visible: true
        ToolIcon
        {
            id: toolBack
            platformIconId: "toolbar-back"
            anchors.left: historyTools.left
            onClicked:
            {
                if(myMenu.status === DialogStatus.Open) myMenu.close()
                pageStack.pop();
            }
        }
        Label
        {
            id: lblTotal
            anchors.right: toolPeriod.left
            text: ""
            anchors.rightMargin: 50
        }
        ToolButton
        {
            id: toolPeriod
            anchors.right: parent.right
            text: "Current month"
            onClicked:  (myMenu.status == DialogStatus.Closed) ? myMenu.open() : myMenu.close()
        }
    }

    Menu
    {
        id: myMenu
        visualParent: pageStack
        MenuLayout
        {
            MenuItem
            {
				id: menuToday
                text: qsTr("Current day")
				onClicked: 
				{
                    toolPeriod.text=qsTr("Current day")
                    sortType=UCountDB.SortType.today
                    init(PageStatus.Active)
				}
            }
            MenuItem
            {
				id: menuMonth
                text: qsTr("Current month")
				onClicked: 
				{
                    toolPeriod.text=qsTr("Current month")
                    sortType=UCountDB.SortType.lastMonth
                    init(PageStatus.Active)
				}				
            }			
            MenuItem
            {
				id: menuYear
                text: qsTr("Current year")
				onClicked: 
				{
                    toolPeriod.text=qsTr("Current year")
                    sortType=UCountDB.SortType.lastYear
                    init(PageStatus.Active)
				}				
            }			
            MenuItem
            {
                id: menuAll
                text: qsTr("Until today")
                onClicked:
                {
                    toolPeriod.text=qsTr("Until today")
                    sortType=UCountDB.SortType.all
                    init(PageStatus.Active)
                }
            }
            MenuItem
            {
                id: menuOneAhead
                text: qsTr("Until next year")
                onClicked:
                {
                    toolPeriod.text=qsTr("Until next year")
                    sortType=UCountDB.SortType.oneAhead
                    init(PageStatus.Active)
                }
            }
        }
    }
  Menu
    {
        id: menuLongPress
        visualParent: pageStack
        MenuLayout
        {
            MenuItem
            {
                id: menuDelete
                text: qsTr("Delete")
				onClicked: 
				{
                    switch(listItemTransactionType)
                    {
                        case Defines.TransactionType.expense:
                            deleteExpense(listItemID)
                            break
                        case Defines.TransactionType.budget:
                            deleteBudget(listItemID)
                            break
                    }
				}				
            }			
        }
    }

  function deleteExpense(id)
  {
      UCountDB.deleteExpense(id)
      init(PageStatus.Active)
  }

  function deleteBudget(id)
  {
      UCountDB.deleteBudget(id)
      init(PageStatus.Active)
  }

  function init(status)
  {
      if(status!==PageStatus.Active)return
        ucountList.listModel.clear()
        var list=UCountDB.readTransactions(UCountDB.currentAccountID,sortType)
        var budgetSum=0
        var expenseSum=0
        var i=0
        for(var v in list)
        {
            var color
            if(list[v].transactionType===UCountDB.TransactionType.expense)
            {
                color="red"
                expenseSum+=list[v].value
            }
            if(list[v].transactionType===UCountDB.TransactionType.budget)
            {
                color="green"
                budgetSum+= list[v].value
            }
            var categoryName
            var iconImage
            UCountDB.getCategory(list[v].categoryid, function(infoCategory)
            {
                 if((!infoCategory) || infoCategory.iconid===0)
                 {
                      if(list[v].transactionType===UCountDB.TransactionType.expense)iconImage="qrc:/Images/unknownexpense.png"
                      if(list[v].transactionType===UCountDB.TransactionType.budget)iconImage="qrc:/Images/unknownbudget.png"
                     categoryName=""
                 }
                 else
                 {
                    categoryName=infoCategory.name
                     UCountDB.getIcon(infoCategory.iconid, function(infoIcon)
                     {
                         iconImage="qrc:/Images/"+infoIcon.qrcpath
                     });
                 }
            });
            var date= new Date(list[v].dateinserted)
            ucountList.listModel.append({"title":list[v].name,
                                            "subtitle":list[v].description,
                                            "value":list[v].value,
                                            "image":iconImage,
                                            "transactionColor":color,
                                            "transactionType":list[v].transactionType,
                                            "tableID":list[v].id,
                                            "dateInserted": Qt.formatDate(date,Qt.DefaultLocaleShortDate),
                                            "showDate":true,
                                            "category":categoryName})
            i++
        }
        var total=budgetSum-expenseSum
        lblTotal.text="Total: "+total.toFixed(2)
        if(total>0)lblTotal.color="green"
        if(total<0)lblTotal.color="red"
        if(total===0)lblTotal.color="steelblue"

        ucountList.pageInfo.showProgress(budgetSum,expenseSum,0)
    }
    onStatusChanged: init(status)
}
