import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.0
import "ucountDB.js" as UCountDB
import "Defines.js" as Defines

Page
{
    id: reportsPage
    tools: reportsTools
    orientationLock: PageOrientation.LockPortrait
    property int secondColumnWidth: 300
    property date startDate:new Date()
    property date endDate:new Date()

    PageTitle
    {
        id: pageTitle
        title: "Reports"
    }

    Grid
    {
        id: grid
        columns: 2
        spacing: 2
        anchors.top: pageTitle.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.leftMargin: Defines.gridLeftMargin
        anchors.topMargin: Defines.gridTopMargin

        Text
        {
            id: lblStartDate
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Start Date")
            anchors.verticalCenter: btnStartDate.verticalCenter
        }
        TumblerButton
        {
            id: btnStartDate
            anchors.right: parent.right
            anchors.rightMargin: 10
            text:Qt.formatDate(startDate,Qt.DefaultLocaleShortDate)
            onClicked: launchStartDate()
            width: secondColumnWidth
        }
        Text
        {
            id: lblEndDate
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("End Date")
            anchors.verticalCenter: btnEndDate.verticalCenter
        }
        TumblerButton
        {
            id: btnEndDate
            text:Qt.formatDate(endDate,Qt.DefaultLocaleShortDate)
            anchors.right: parent.right
            anchors.rightMargin: 10
            onClicked: launchEndDate()
            width: secondColumnWidth
        }
        Text
        {
            id: lblShowExpenses
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Expenses")
            anchors.verticalCenter: radioExpenses.verticalCenter
        }
        RadioButton
        {
            id: radioExpenses
            checked:true
            anchors.right: parent.right
            onClicked:
            {
                radioBudget.checked=(!checked)
                radioTransfer.checked=(!checked)
                radioSavings.checked=(!checked)
            }
        }
        Text
        {
            id: lblShowBudgets
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Budgets")
            anchors.verticalCenter: radioBudget.verticalCenter
        }
        RadioButton
        {
            id: radioBudget
            anchors.right: parent.right
            onClicked:
            {
                radioExpenses.checked=(!checked)
                radioTransfer.checked=(!checked)
                radioSavings.checked=(!checked)
            }
        }
        Text
        {
            id: lblTransfers
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Transfers")
            anchors.verticalCenter: radioTransfer.verticalCenter
        }
        RadioButton
        {
            id: radioTransfer
            anchors.right: parent.right
            onClicked:
            {
                radioBudget.checked=(!checked)
                radioExpenses.checked=(!checked)
                radioSavings.checked=(!checked)
            }
        }
        Text
        {
            id: lblSavings
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Savings")
            anchors.verticalCenter: radioSavings.verticalCenter
        }
        RadioButton
        {
            id: radioSavings
            anchors.right: parent.right
            onClicked:
            {
                radioBudget.checked=(!checked)
                radioTransfer.checked=(!checked)
                radioExpenses.checked=(!checked)
            }
        }
    }
    Image
    {
        id: imgHorizontalRow
        source: "qrc:/Images/horizontalLine.png"
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.rightMargin: Defines.listViewRightMargin
        anchors.leftMargin: Defines.listViewLeftMargin
        anchors.top: grid.bottom
    }
    DatePickerDialog
    {
         id: dateStartDialog
         titleText: "Start Date"
        minimumYear: 2005
        onAccepted: startDateCallback()
     }
    DatePickerDialog
    {
         id: dateEndDialog
         titleText: "End Date"
         minimumYear: 2005
         onAccepted: endDateCallback()
     }
    Button
    {
        anchors.top: imgHorizontalRow.bottom
        anchors.topMargin: 30
        anchors.horizontalCenter: parent.horizontalCenter
        text: "Generate"
        style: PositiveButtonStyle {}
        onClicked: generate()
    }
    ErrorDialog
    {
        id: errorDialog
    }
    ToolBarLayout
    {
        id: reportsTools
        visible: true
        ToolIcon
        {
            id: toolBack
            platformIconId: "toolbar-back"
            anchors.left: parent.left
            onClicked: pageStack.pop();
        }
    }
    function launchStartDate()
    {
         dateStartDialog.year = startDate.getFullYear();
         dateStartDialog.month = startDate.getMonth()+1;
         dateStartDialog.day = startDate.getDate();
         dateStartDialog.open();
     }
    function startDateCallback()
    {
        startDate=Defines.getDateFromDatePickerDialog(dateStartDialog.year,dateStartDialog.month,dateStartDialog.day)
        btnStartDate.text=Qt.formatDate(startDate,Qt.DefaultLocaleShortDate)
    }
    function launchEndDate()
    {
         dateEndDialog.year = endDate.getFullYear();
         dateEndDialog.month = endDate.getMonth()+1;
         dateEndDialog.day = endDate.getDate();
         dateEndDialog.open();
     }
    function endDateCallback()
    {
        endDate=Defines.getDateFromDatePickerDialog(dateEndDialog.year,dateEndDialog.month,dateEndDialog.day)
        btnEndDate.text=Qt.formatDate(endDate,Qt.DefaultLocaleShortDate)
    }
    function generate()
    {
        if(startDate>endDate)
        {
            errorDialog.text="Start Date must be before End Date"
            errorDialog.open()
            return
        }
        var page=UCountDB.getPage(UCountDB.PageType.reportsResult)
        pageStack.push(page,{startDate: startDate,
                            endDate:endDate,
                            showExpenses: radioExpenses.checked,
                            showBudgets: radioBudget.checked,
                            showTransfers: radioTransfer.checked,
                            showSavings: radioSavings.checked,
                            pieType: false,
                            barType: true})
    }
}
