import QtQuick 1.1
import com.nokia.meego 1.0
import "ucountDB.js" as UCountDB
import "Defines.js" as Defines

Page
{
    id: reportsPage
    tools: reportsTools
    orientationLock: PageOrientation.LockPortrait
    property int secondColumnWidth: 300
    property date startDate:null
    property date endDate:null
    property bool showExpenses:false
    property bool showBudgets:false
    property bool showTransfers:false
    property bool showSavings:false
    property bool pieType:false
    property bool barType:false
    property int progressMaximum:0

    PageTitle
    {
        id: pageTitle
        title: "Report Result"
    }
    ListModel
    {
        id: ucountModel
        ListElement
        {
            title: ""
            value: 0
            display: 0
            image: ""
            category: ""
            transactionColor: "black"
        }
    }
    Label
    {
        id: lblNoData
        text: qsTr("No transaction available")
        color: "red"
        font.family: Defines.fontFamily
        font.pointSize: Defines.fontSize
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        visible: false
    }

    ListView
    {
            id: listView
            anchors.top: pageTitle.bottom
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.bottom: parent.bottom
            anchors.leftMargin: Defines.listViewLeftMargin
            anchors.rightMargin: Defines.listViewRightMargin
            anchors.topMargin: Defines.listViewTopMargin
            model: ucountModel
            clip: true

            delegate:  Item
            {
                id: listItem
                height: Defines.listViewItensHeight
                width: parent.width
                property variant itemData: model

                BorderImage
                {
                    id: background
                    anchors.fill: parent
                    anchors.leftMargin: -parent.anchors.leftMargin
                    anchors.rightMargin: -parent.anchors.rightMargin
                    visible: mouseArea.pressed
                }

                Label
                {
                    id: mainText
                    text: model.category
                    font.weight: Font.Bold
                    font.family: Defines.listViewItensMainTextFontFamily
                    font.pixelSize: 15
                    width: 90
                    anchors.verticalCenter: progress.verticalCenter
                }

                ReportProgress
                {
                    id: progress
                    anchors.left: mainText.right
                    visible: true
                    maximum: progressMaximum
                    value: model.value
                    display: model.display
                    color: model.transactionColor
                }

                MouseArea
                {
                    id: mouseArea
                    anchors.fill: background
                }
            }
        }
        ScrollDecorator
        {
            flickableItem: listView
        }
    ToolBarLayout
    {
        id: reportsTools
        visible: true
        ToolIcon
        {
            id: toolBack
            platformIconId: "toolbar-back"
            anchors.left: parent.left
            onClicked: pageStack.pop();
        }
    }

    function init()
    {
        ucountModel.clear()
        lblNoData.visible=false
        var list
        var color
        if(showExpenses)
        {
            list=UCountDB.readExpensesByCategory(UCountDB.currentAccountID, startDate, endDate)
            color="red"
        }
        if(showBudgets)
        {
            list=UCountDB.readBudgetsByCategory(UCountDB.currentAccountID, startDate, endDate)
            color="green"
        }
        if(showTransfers)
        {
            list=UCountDB.readTransfersByCategory(UCountDB.currentAccountID, startDate, endDate)
            color="blue"
        }
        if(showSavings)
        {
            list=UCountDB.readSavingsByCategory(UCountDB.currentAccountID, startDate, endDate)
            color="yellow"
        }
        if(list.length===0)
        {
            lblNoData.visible=true
            return
        }

        var expenseSum=0
        for(var v1 in list)
            if(parseInt(list[v1].value)>progressMaximum)progressMaximum=parseInt(list[v1].value)
        for(var v in list)
        {
            var categoryName=""
            UCountDB.getCategory(list[v].categoryid, function(infoCategory)
            {
                 if((!infoCategory) || infoCategory.iconid===0)categoryName=""
                 else categoryName=infoCategory.name
            });
            if(categoryName.length===0)categoryName="Unknown"
            ucountModel.append({"title":list[v].name,
                                            "value":parseInt(list[v].value),
                                            "display":parseFloat(list[v].value),
                                            "category":categoryName,
                                            "transactionColor":color})
        }
    }
    Component.onCompleted:  init()
}
