import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.0
import "ucountDB.js" as UCountDB
import "Defines.js" as Defines

Page
{
    id: savingsAddEditPage
    orientationLock: PageOrientation.LockPortrait
    property int secondColumnWidth: 360
    property int categoryID:0
    property int savingID:0
    property date transactionDate:new Date()

    PageTitle
    {
        id: pageTitle
        title: "Add Saving"
        btnDoneVisible: true
        btnCancelVisible: true
        onCancelled:  pageStack.pop()
        onDone: saveSaving()
    }

    Grid
    {
        id: grid
        anchors.top: pageTitle.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        anchors.leftMargin: Defines.gridLeftMargin
        columns: 2
        spacing: 2
        anchors.topMargin: UCountDB.gridTopMargin
        Text
        {
            id: lblValue
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Value")
            anchors.verticalCenter: txtValue.verticalCenter
        }
        TextField
        {
            id: txtValue
            width: secondColumnWidth
            validator: DoubleValidator{}
            inputMethodHints: Qt.ImhDigitsOnly | Qt.ImhNoPredictiveText
        }
        Text
        {
            id: lblName
            font.family: UCountDB.fontFamily
            font.pointSize: UCountDB.fontSize
            text: qsTr("Name")
            anchors.verticalCenter: txtName.verticalCenter
        }
        TextField
        {
            id: txtName
            width: secondColumnWidth
        }
        Text
        {
            id: lblDescription
            font.family: UCountDB.fontFamily
            font.pointSize: UCountDB.fontSize
            text: qsTr("Note")
            anchors.verticalCenter: txtDescription.verticalCenter
        }
        TextField
        {
            id: txtDescription
            width: secondColumnWidth
        }
        Text
        {
            id: lblDate
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Date")
            anchors.verticalCenter: btnDate.verticalCenter
        }
        TumblerButton
        {
            id: btnDate
            text:Qt.formatDate(transactionDate,Qt.DefaultLocaleShortDate)
            width: secondColumnWidth
            onClicked: launchDate()
        }
        Text
        {
            id: lblCategory
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Category")
            anchors.verticalCenter: btnCategory.verticalCenter
        }
        TumblerButton
        {
            id: btnCategory
            text: " "
            onClicked: categoryDialog.open()
            width: secondColumnWidth
        }
    }
    SelectionDialog
    {
        id: categoryDialog
        titleText: "Categories available"
        selectedIndex: 0
        onAccepted:
        {
            btnCategory.text= model.get(selectedIndex).name
            categoryID=model.get(selectedIndex).tableID
        }
        model: ListModel
        {
            id: categoryModel
            ListElement
            {
                name: ""
                tableID: 0
            }
        }
    }
    ErrorDialog
    {
        id: errorDialog
    }
    DatePickerDialog
    {
         id: dateDialog
        minimumYear: 2005
         titleText: "Date of expense"
         onAccepted: dateCallback()
     }
    function launchDate()
    {
         dateDialog.year = transactionDate.getFullYear();
         dateDialog.month = transactionDate.getMonth()+1;
         dateDialog.day = transactionDate.getDate();
         dateDialog.open();
     }
    function dateCallback()
    {
        transactionDate=Defines.getDateFromDatePickerDialog(dateDialog.year,dateDialog.month,dateDialog.day)
        btnDate.text=Qt.formatDate(transactionDate,Qt.DefaultLocaleShortDate)
    }
    function saveSaving()
    {
        if(txtValue.text.length<1)
        {
            errorDialog.text="Set a value"
            errorDialog.open()
            return
        }
        if(txtName.text.length<1)
        {
            errorDialog.text="Set a name"
            errorDialog.open()
            return
        }
        UCountDB.saveSaving(savingID,UCountDB.currentAccountID,txtName.text,txtDescription.text,transactionDate,txtValue.text,categoryID)
        pageStack.pop()
    }
    function getSaving()
    {
        categoryModel.clear()
        var listCategories=UCountDB.readTopLevelCategories()
        for(var vCategory in listCategories)categoryModel.append({"name":listCategories[vCategory].name,"tableID":listCategories[vCategory].id})
        if(savingID==0)return
        UCountDB.getSaving(savingID, function(info)
       {
           pageTitle.title="Edit Saving"
           txtValue.text=info.value
           txtName.text=info.name
           txtDescription.text=info.description
           transactionDate= new Date(info.dateinserted)
           btnDate.text=Qt.formatDate(transactionDate,Qt.DefaultLocaleShortDate)
           UCountDB.getCategory(info.categoryid,function(infoCategory)
           {
              if(!infoCategory)
              {
                  categoryID=0
                  btnCategory.text="..."
              }else
               {
                  categoryID=infoCategory.id
                  btnCategory.text=infoCategory.name
              }
           });
       });
    }
    Component.onCompleted:  getSaving()
}
