import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.0
import "ucountDB.js" as UCountDB
import "Defines.js" as Defines

Page
{
    id: transferAddEditPage
    orientationLock: PageOrientation.LockPortrait
    property int transferID: 0
    property int secondColumnWidth: 360
    property int accountToID: 0
    property date transactionDate:new Date()
    property int categoryID:0

    PageTitle
    {
        id: pageTitle
        title: "New Transfer"
        btnDoneVisible: true
        btnCancelVisible: true
        onCancelled:  pageStack.pop()
        onDone: saveTransfer()
    }

    Grid
    {
        columns: 2
        spacing: 2
        anchors.top: pageTitle.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        anchors.leftMargin: Defines.gridLeftMargin
        anchors.topMargin: UCountDB.gridTopMargin

        Text
        {
            id: lblValue
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Value")
            anchors.verticalCenter: txtValue.verticalCenter
        }
        TextField
        {
            id: txtValue
            width: secondColumnWidth
            validator: DoubleValidator{}
            inputMethodHints: Qt.ImhDigitsOnly | Qt.ImhNoPredictiveText
        }
        Text
        {
            id: lblName
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Name")
            anchors.verticalCenter: txtName.verticalCenter
        }
        TextField
        {
            id: txtName
            width: secondColumnWidth
        }
        Text
        {
            id: lblDescription
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Note")
            anchors.verticalCenter: txtDescription.verticalCenter
        }
        TextField
        {
            id: txtDescription
            width: secondColumnWidth
        }
        Text
        {
            id: lblDate
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Date")
            anchors.verticalCenter: btnDate.verticalCenter
        }
        TumblerButton
        {
            id: btnDate
            text:Qt.formatDate(transactionDate,Qt.DefaultLocaleShortDate)
            width: secondColumnWidth
            onClicked: launchDate()
        }
        Text
        {
            id: lblCategory
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Category")
            anchors.verticalCenter: btnCategory.verticalCenter
        }
        TumblerButton
        {
            id: btnCategory
            text: " "
            onClicked: categoryDialog.open()
            width: secondColumnWidth
        }
        Text
        {
            id: lblTo
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("To")
            anchors.verticalCenter: btnTo.verticalCenter
        }
        TumblerButton
        {
            id: btnTo
            text: " "
            onClicked: toDialog.open()
            width: secondColumnWidth
        }
    }
    SelectionDialog
    {
        id: categoryDialog
        titleText: "Categories available"
        selectedIndex: 0
        onAccepted:
        {
            btnCategory.text= model.get(selectedIndex).name
            categoryID=model.get(selectedIndex).tableID
        }
        model: ListModel
        {
            id: categoryModel
            ListElement
            {
                name: ""
                tableID: 0
            }
        }
    }
    SelectionDialog
    {
        id: toDialog
        titleText: "Accounts available"
        selectedIndex: 1
        onAccepted:
        {
            btnTo.text= model.get(selectedIndex).name
            accountToID=model.get(selectedIndex).tableID
        }
        model: ListModel
        {
            id: accountModel
            ListElement
            {
                name: ""
                tableID: 0
            }
        }
    }
    ErrorDialog
    {
        id: errorDialog
    }
    DatePickerDialog
    {
         id: dateDialog
         titleText: "Date of expense"
         onAccepted: dateCallback()
     }
    function launchDate()
    {
         dateDialog.year = transactionDate.getFullYear();
         dateDialog.month = transactionDate.getMonth()+1;
         dateDialog.day = transactionDate.getDate();
         dateDialog.open();
     }
    function dateCallback()
    {
        transactionDate=Defines.getDateFromDatePickerDialog(dateDialog.year,dateDialog.month,dateDialog.day)
        btnDate.text=Qt.formatDate(transactionDate,Qt.DefaultLocaleShortDate)
    }
    function saveTransfer()
    {
        if(txtValue.text.length<1)
        {
            errorDialog.text="Set a value"
            errorDialog.open()
            return
        }
        if(txtName.text.length<1)
        {
            errorDialog.text="Set a name"
            errorDialog.open()
            return
        }
        if(accountToID==0)
        {
            errorDialog.text="Select the account"
            errorDialog.open()
            return
        }

        UCountDB.saveTransfer(transferID, UCountDB.currentAccountID, accountToID, txtName.text,txtDescription.text,transactionDate ,txtValue.text, categoryID, Defines.RepeatType.once)
         pageStack.pop()
    }
    function getTransfer()
    {
        accountModel.clear()
        var list=UCountDB.readAccountsExceptCurrent(UCountDB.currentAccountID)
        for(var v in list)accountModel.append({"name":list[v].name,"tableID":list[v].id})
        accountModel.append({"name":"Savings","tableID":UCountDB.currentAccountID})
        categoryModel.clear()
        var listCategories=UCountDB.readTopLevelCategories()
        for(var vCategory in listCategories)categoryModel.append({"name":listCategories[vCategory].name,"tableID":listCategories[vCategory].id})
        if(transferID==0)return
        UCountDB.getTransfer(transferID, function(info)
        {
            accountToID=info.accounttoid
             transactionDate= new Date(info.dateinserted)
             btnDate.text=Qt.formatDate(transactionDate,Qt.DefaultLocaleShortDate)
             UCountDB.getAccount(info.accounttoid,function(infoToAccount)
             {
                 btnTo.text=infoToAccount.name
             });
             UCountDB.getCategory(info.categoryid,function(infoCategory)
             {
                  if(!infoCategory)
                  {
                      categoryID=0
                      btnCategory.text=" "
                  }else
                   {
                        categoryID=infoCategory.id
                        btnCategory.text=infoCategory.name
                    }
             });
            pageTitle.title="Edit Transfer"
            txtValue.text=info.value
            txtName.text=info.name
            txtDescription.text=info.description
        });
    }
    Component.onCompleted:  getTransfer()
}
