import QtQuick 1.1
import com.nokia.meego 1.0
import "ucountDB.js" as UCountDB
import "Defines.js" as Defines

Page
{
    id: transfersPage
    tools: transfersTools
    orientationLock: PageOrientation.LockPortrait
    property int listItemID:0
    property int sortType: UCountDB.SortType.lastMonth
    UCountList
    {
        id: ucountList
        title: "Transfers"
        onListItemClicked:
        {
            var page=UCountDB.getPage(UCountDB.PageType.transfersAddEdit)
            pageStack.push(page,{transferID: id})
        }
        onListItemPressAndHold:
        {
            listItemID=id
            menuLongPress.open()
        }
    }

    ToolBarLayout
    {
        id: transfersTools
        visible: true
        ToolIcon
        {
            id: toolBack
            platformIconId: "toolbar-back"
            anchors.left: parent.left
            onClicked:
            {
                if(myMenu.status === DialogStatus.Open) myMenu.close()
                pageStack.pop();
            }
        }
        ToolButton
        {
            id: toolPeriod
            anchors.horizontalCenter: parent.horizontalCenter
            text: "Current month"
            onClicked:  (myMenu.status == DialogStatus.Closed) ? myMenu.open() : myMenu.close()
        }
        ToolIcon
        {
            id: toolAdd
            platformIconId: "toolbar-add"
            anchors.right: parent.right
            onClicked:
            {
                var page=UCountDB.getPage(UCountDB.PageType.transfersAddEdit)
                pageStack.push(page)
            }
        }
    }
    Menu
    {
        id: myMenu
        visualParent: pageStack
        MenuLayout
        {
            MenuItem
            {
                id: menuToday
                text: qsTr("Current day")
                onClicked:
                {
                    toolPeriod.text=qsTr("Current day")
                    sortType=UCountDB.SortType.today
                    init(PageStatus.Active)
                }
            }
            MenuItem
            {
                id: menuMonth
                text: qsTr("Current month")
                onClicked:
                {
                    toolPeriod.text=qsTr("Current month")
                    sortType=UCountDB.SortType.lastMonth
                    init(PageStatus.Active)
                }
            }
            MenuItem
            {
                id: menuYear
                text: qsTr("Current year")
                onClicked:
                {
                    toolPeriod.text=qsTr("Current year")
                    sortType=UCountDB.SortType.lastYear
                    init(PageStatus.Active)
                }
            }
            MenuItem
            {
                id: menuAll
                text: qsTr("Until today")
                onClicked:
                {
                    toolPeriod.text=qsTr("Until today")
                    sortType=UCountDB.SortType.all
                    init(PageStatus.Active)
                }
            }
            MenuItem
            {
                id: menuOneAhead
                text: qsTr("Until next year")
                onClicked:
                {
                    toolPeriod.text=qsTr("Until next year")
                    sortType=UCountDB.SortType.oneAhead
                    init(PageStatus.Active)
                }
            }
        }
    }
  Menu
    {
        id: menuLongPress
        visualParent: pageStack
        MenuLayout
        {
            MenuItem
            {
                id: menuDelete
                text: qsTr("Delete")
				onClicked: 
				{
                    UCountDB.deleteTransfer(listItemID)
                    init(PageStatus.Active)
				}				
            }			
        }
    }
    function init(status)
    {
        if(status!==PageStatus.Active)return
        ucountList.listModel.clear()
        var list=UCountDB.readTransfers( UCountDB.currentAccountID,sortType)
        var transferSum=0        
        var i=0
        var lastDate
        for(var v in list)
        {
            transferSum+= list[v].value
            var accountName
            var categoryName
            var iconImage
            UCountDB.getCategory(list[v].categoryid, function(infoCategory)
            {
                 if(!infoCategory || infoCategory.iconid===0)
                 {
                     iconImage="qrc:/Images/unknowntransfer.png"
                     categoryName=""
                 }
                 else
                 {
                    categoryName=infoCategory.name
                     UCountDB.getIcon(infoCategory.iconid, function(infoIcon)
                     {
                         iconImage="qrc:/Images/"+infoIcon.qrcpath
                     });
                 }
            });
            UCountDB.getAccount(list[v].accounttoid,function(info)
            {
                accountName=info.name
            });
            var showDate=false
            var date= new Date(list[v].dateinserted)
            if(i==0)
            {
                lastDate=new Date(list[v].dateinserted)
                showDate=true
            }else
            {
                if(lastDate.getFullYear()===date.getFullYear() && lastDate.getMonth()===date.getMonth() && lastDate.getDate()===date.getDate())showDate=false
                else
                {
                    showDate=true
                    lastDate=date
                }

            }
            var to="to "
            if(parseInt(list[v].accounttoid)===parseInt(UCountDB.currentAccountID))to+="Savings"
            else to+=accountName
            ucountList.listModel.append({"title":list[v].name,
                                            "value":list[v].value,
                                            "image":list[v].image,
                                            "tableID":list[v].id,
                                            "subtitle":to,
                                            "category":"",
                                            "image":iconImage,
                                            "dateInserted": Qt.formatDate(date,Qt.DefaultLocaleShortDate),
                                            "showDate":showDate,
                                            "transactionColor":"blue",
                                            "categoryName":categoryName})
            i++
        }
        ucountList.pageInfo.showProgress(0,0,transferSum)
    }
    onStatusChanged: init(status)
}
