import QtQuick 1.1
import com.nokia.meego 1.0
import "ucountDB.js" as UCountDB
import "Defines.js" as Defines

Page
{
    id: vendorsPage
    tools: vendorsTools
    orientationLock: PageOrientation.LockPortrait
    property int listItemID:0
    UCountList
    {
        id: ucountList
        title: "Vendors"
        onListItemClicked:
        {
            var page=UCountDB.getPage(UCountDB.PageType.vendorsAddEdit)
            pageStack.push(page,{vendorID: id})
        }
        onListItemPressAndHold:
        {
            listItemID=id
            menuLongPress.open()
        }
    }
    ToolBarLayout
    {
        id: vendorsTools
        visible: true
        ToolIcon
        {
            id: toolBack
            platformIconId: "toolbar-back"
            anchors.left: parent.left
            onClicked: pageStack.pop();
        }
        ToolIcon
        {
            id: toolAdd
            platformIconId: "toolbar-add"
            anchors.right: parent.right
            onClicked:
            {
                var page=UCountDB.getPage(UCountDB.PageType.vendorsAddEdit)
                pageStack.push(page)
            }
        }
    }
	Menu
    {
        id: menuLongPress
        visualParent: pageStack
        MenuLayout
        {
            MenuItem
            {
                id: menuDelete
                text: qsTr("Delete")
				onClicked: 
				{
                    UCountDB.deleteVendor(listItemID)
                    init(PageStatus.Active)
				}				
            }			
        }
    }		
    function init(status)
    {
        if(status!==PageStatus.Active)return
        ucountList.listModel.clear()
        var list=UCountDB.readVendors()
        for(var v in list)
        {
            var categoryName
            var iconImage
            UCountDB.getCategory(list[v].categoryid, function(infoCategory)
            {
                 if(!infoCategory || infoCategory.iconid===0)
                 {
                     iconImage="qrc:/Images/unknownvendor.png"
                     categoryName=""
                 }
                 else
                 {
                    categoryName=infoCategory.name
                     UCountDB.getIcon(infoCategory.iconid, function(infoIcon)
                     {
                         iconImage="qrc:/Images/"+infoIcon.qrcpath
                     });
                 }
            });
            ucountList.listModel.append({"title":list[v].name,
                                            "subtitle":list[v].description,
                                            "image":iconImage,
                                            "tableID":list[v].id,
                                            "dateInserted":"",
                                            "showDate":false,
                                            "transactionColor":"black",
                                            "value":0,
                                            "category":categoryName})
        }
    }
    onStatusChanged: init(status)
}
