import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.0
import "ucountDB.js" as UCountDB
import "Defines.js" as Defines

Page
{
    id: vendorsAddEditPage
    orientationLock: PageOrientation.LockPortrait
    property int vendorID: 0
    property int secondColumnWidth: 360
    property int categoryID:0

    PageTitle
    {
        id: pageTitle
        title: "New Vendor"
        btnDoneVisible: true
        btnCancelVisible: true
        onCancelled:  pageStack.pop()
        onDone: saveVendor()
    }

    Grid
    {
        columns: 2
        spacing: 2
        anchors.top: pageTitle.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        anchors.leftMargin: Defines.gridLeftMargin
        anchors.topMargin: Defines.gridTopMargin
        Text
        {
            id: lblName
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Name")
            anchors.verticalCenter: txtName.verticalCenter
        }
        TextField
        {
            id: txtName
            width: secondColumnWidth
        }
        Text
        {
            id: lblDescription
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Note")
            anchors.verticalCenter: txtDescription.verticalCenter
        }
        TextField
        {
            id: txtDescription
            width: secondColumnWidth
        }
        Text
        {
            id: lblCategory
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Category")
            anchors.verticalCenter: btnCategory.verticalCenter
        }
        TumblerButton
        {
            id: btnCategory
            text: " "
            onClicked: categoryDialog.open()
            width: secondColumnWidth
        }
    }
    SelectionDialog
    {
        id: categoryDialog
        titleText: "Categories available"
        selectedIndex: 0
        onAccepted:
        {
            btnCategory.text= model.get(selectedIndex).name
            categoryID=model.get(selectedIndex).tableID
        }
        model: ListModel
        {
            id: categoryModel
            ListElement
            {
                name: ""
                tableID: 0
            }
        }
    }
    ErrorDialog
    {
        id: errorDialog
    }
    function saveVendor()
    {
        if(txtName.text.length<1)
        {
            errorDialog.text="Set a name"
            errorDialog.open()
            return
        }
        if(categoryID==0)
        {
            errorDialog.text="Set a category"
            errorDialog.open()
            return
        }
        UCountDB.saveVendor(vendorID, txtName.text,txtDescription.text,categoryID)
        pageStack.pop()
    }
    function getVendor()
    {
        categoryModel.clear()
        var listCategories=UCountDB.readTopLevelCategories()
        for(var vCategory in listCategories)categoryModel.append({"name":listCategories[vCategory].name,"tableID":listCategories[vCategory].id})
        if(vendorID==0)return
        UCountDB.getVendor(vendorID, function(info)
        {
            pageTitle.title="Edit Vendor"
            txtName.text=info.name
            txtDescription.text=info.description
           UCountDB.getCategory(info.categoryid,function(infoCategory)
           {
               btnCategory.text=infoCategory.name
               categoryID=infoCategory.id
           });
        });
    }
    Component.onCompleted:  getVendor()
}
