.pragma library
Qt.include("Defines.js")


/**
  *Return the accounts
  */
function readAccounts(sortType)
{
    var list = {}
    db.readTransaction( function(tx)
    {
        var rs = tx.executeSql("SELECT * FROM accounts ORDER BY name DESC");
        var item
        for (var i=0; i< rs.rows.length; i++)
        {
            item = rs.rows.item(i)
            item.image="qrc:/Images/unknownaccount.png"
            item.defaultaccount=parseInt(item.defaultaccount)
            list[item.id] = item;
        }
    });
    return list;
}


/**
  *Return the accounts except current account
  */
function readAccountsExceptCurrent(currentAccountID)
{
    var list = {}
    db.readTransaction( function(tx)
    {
        var rs = tx.executeSql("SELECT * FROM accounts where id != ? ORDER BY name DESC",currentAccountID);
        var item
        for (var i=0; i< rs.rows.length; i++)
        {
            item = rs.rows.item(i)
            item.defaultaccount=parseInt(item.defaultaccount)
            item.image="qrc:/Images/unknownaccount.png"
            list[item.id] = item;
        }
    });
    return list;
}

/**
  *Get a account specified by accountID
  */
function getAccount(accountID,callback)
{
    db.transaction( function(tx)
    {
       var resultSet=tx.executeSql("select * from accounts where id = ?",accountID);
       if (resultSet.rows.length > 0)
       {
           var item=resultSet.rows.item(0)
           item.defaultaccount=parseInt(item.defaultaccount)
           callback(item)
       }
    });
}

/**
  *Delete the account specified by accountID
  */
function deleteAccount(accountID)
{
    db.transaction( function(tx)
    {
        tx.executeSql("DELETE FROM accounts where id = ?",accountID);
        tx.executeSql("DELETE FROM budgets where accountid = ?",accountID);
        tx.executeSql("DELETE FROM expenses where accountid = ?",accountID);
        tx.executeSql("DELETE FROM savings where accountid = ?",accountID);
        tx.executeSql("DELETE FROM transfers where accountfromid = ?",accountID);
    });
}


/**
  *Return the default account
  */
function getDefaultAccount(callback)
{
    db.transaction( function(tx)
    {
       var resultSet=tx.executeSql("select * from accounts where defaultaccount = 1");
       if (resultSet.rows.length > 0)
       {
           var item=resultSet.rows.item(0)
           item.defaultaccount=parseInt(item.defaultaccount)
           callback(item)
       }
    });
}


/**
  *Save a account
  */
function saveAccount(id, name, description, defaultAccount)
{
    var xID=parseInt(id)
    var xName=name
    var xDescription=description
    var xDefaultAccount
    if(defaultAccount===true)xDefaultAccount=1
    else xDefaultAccount=0

    //let's deselect all others
    if(xDefaultAccount)
    db.transaction( function(tx)
    {
        tx.executeSql("update accounts  set defaultaccount=0");
    });


    if(xID>0)//update
    {
        db.transaction( function(tx)
        {
            tx.executeSql("update accounts set name=?, description=?, defaultaccount=? where id= ?",
                          [xName,xDescription,xDefaultAccount,xID]);
        });
        if(xDefaultAccount)currentAccountID=id
    }
    else//insert
    {
        db.transaction( function(tx)
        {
            var result=tx.executeSql("insert into accounts ( name, description, defaultaccount ) VALUES(?,?,?)",
                          [xName,xDescription,xDefaultAccount]);
            if(xDefaultAccount)currentAccountID=result.insertId
        });
    }
}
