.pragma library
Qt.include("Defines.js")
Qt.include("Recurrences.js")

/**
  *Return the expenses
  */
function readExpenses(accountID, sortType)
{
    var transactions=new Transactions()
    db.readTransaction( function(tx)
    {
        var rs = tx.executeSql("SELECT * FROM expenses where accountid= ? ORDER BY dateinserted DESC",accountID);
        var item
        var transaction
        for (var i=0; i< rs.rows.length; i++)
        {
            item = rs.rows.item(i)
            transaction=new Transaction(item.id, parseInt(TransactionType.expense),item.accountid, item.name, item.description, item.dateinserted,parseFloat(item.value),item.categoryid, item.vendorid, item.repeat)
            transactions.append(transaction)
        }
    });
    var list
    if(sortType===SortType.oneAhead) list=transactions.getListSortedWithRecurrences(true)
    else list=transactions.getListSortedWithRecurrences(false)
    if(sortType===SortType.today)return getOnlyToday(list)
    if(sortType===SortType.lastMonth)return getOnlyLastMonth(list)
    if(sortType===SortType.lastYear)return getOnlyCurrentYear(list)
    if(sortType===SortType.all)return list
    return list
}


/**
  *Return the expenses transactions by category
  */
function readExpensesByCategory(accountID,startDate, endDate)
{
    var transactions=new Transactions()
    db.readTransaction( function(tx)
    {
        var rs = tx.executeSql("SELECT * FROM expenses where accountid= ? ORDER BY categoryid DESC",accountID);
        var item
        var transaction
        for (var i=0; i< rs.rows.length; i++)
        {
            item = rs.rows.item(i)
            transaction=new Transaction(item.id, parseInt(TransactionType.expense),item.accountid, item.name, item.description, item.dateinserted,parseFloat(item.value),item.categoryid, item.vendorid, item.repeat)
            transactions.append(transaction)
        }
    });
    return transactions.getCategoriesList(startDate, endDate)
}


/**
  *Get a expense specified by expenseID
  */
function getExpense(expenseID,callback)
{
    db.transaction( function(tx)
    {
       var resultSet=tx.executeSql("select * from expenses where id = ?",expenseID);
       if (resultSet.rows.length > 0)callback(resultSet.rows.item(0))
    });
}

/**
  *Save a expense
  */
function saveExpense(id, accountid, name, description, dateinserted, value, categoryid, vendorid, vat,repeatID)
{
    var xID=parseInt(id)
    var xAccountID=parseInt(accountid)
    var xName=name
    var xDescription=description
    var xDateInserted
    var xValue=parseFloat(value).toString()
    var xRepeatID=parseInt(repeatID)
    var xCategoryID=parseInt(categoryid)
    var xVendorID=parseInt(vendorid)
    var xVat=parseFloat(vat).toString()    
    xDateInserted=getStringFromDateToSaveInSqlite(dateinserted)
    if(xID>0)//update
    {
        db.transaction( function(tx)
        {
            tx.executeSql("update expenses set accountid= ?, name= ?, description= ?, dateinserted= ?, value= ?, categoryid= ?, vendorid= ?,vat= ?, repeat=? where id= ?",
                          [xAccountID,xName,xDescription,xDateInserted,xValue,xCategoryID,xVendorID,xVat,xRepeatID, xID]);
        });
    }
    else//insert
    {
        db.transaction( function(tx)
        {
            tx.executeSql("insert into expenses (accountid, name, description, dateinserted, value, categoryid, vendorid, vat, repeat ) VALUES(?,?,?,?,?,?,?,?,?)",
                          [xAccountID,xName,xDescription,xDateInserted,xValue,xCategoryID,xVendorID,xVat, xRepeatID]);
        });
    }
}


/**
  *Delete the expense specified by expenseID
  */
function deleteExpense(expenseID)
{    
    db.transaction( function(tx)
    {
        tx.executeSql("DELETE FROM expenses where id = ?",expenseID);
    });
}
