import QtQuick 1.1
import com.nokia.meego 1.0
import "ucountDB.js" as UCountDB
import "Defines.js" as Defines

Page
{
    id: mainPage
    tools: commonTools
    orientationLock: PageOrientation.LockPortrait

    PageTitle
    {
        id: pageTitle
        title: "UCount"
        accountName: " "
        lblAccountVisible: true
    }

    ListModel
    {
        id: pagesModel
        ListElement
        {
            title: "History"
            page: 15
            image: "qrc:/Images/history.png"            
        }
        ListElement
        {
            title: "Expenses"
            page: 1
            image: "qrc:/Images/expenses.png"
        }
        ListElement
        {
            title:  "Budgets"
            page: 3
            image: "qrc:/Images/budgets.png"
        }
        ListElement
        {
            title:  "Transfers"
            page: 5
            image: "qrc:/Images/transfers.png"
        }
        ListElement
        {
            title:  "Categories"
            page: 12
            image: "qrc:/Images/categories.png"
        }
        ListElement
        {
            title:  "Reports"
            page: 13
            image: "qrc:/Images/reports.png"
        }
        ListElement
        {
            title:  "Vendors"
            page: 7
            image: "qrc:/Images/vendors.png"
        }
        ListElement
        {
            title:  "Savings"
            page: 19
            image: "qrc:/Images/savings.png"
        }
        ListElement
        {
            title:  "Preferences"
            page: 21
            image: "qrc:/Images/preferences.png"
        }
    }

    ListView
    {
            id: listView
            anchors.top: pageTitle.bottom
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.bottom: parent.bottom
            anchors.topMargin: UCountDB.listViewTopMargin
            model: pagesModel
            clip: true

            delegate:  Item
            {
                id: listItem
                height: Defines.listViewTopItensHeight
                width: parent.width

                BorderImage
                {
                    id: background
                    anchors.fill: parent
                    // Fill page borders
                    anchors.leftMargin: -mainPage.anchors.leftMargin
                    anchors.rightMargin: -mainPage.anchors.rightMargin
                    visible: mouseArea.pressed
                    //source: "qrc:/Images/preferences.png"
                }

                Image
                {
                    id: imagem
                    source: model.image
                    anchors.left: parent.left;
                    width: Defines.listViewTopImageSize
                    height: Defines.listViewTopImageSize
                    anchors.leftMargin: Defines.listViewLeftMargin
                    anchors.verticalCenter: parent.verticalCenter
                }

                Row
                {
                    anchors.fill: parent
                    anchors.leftMargin: 100
                    Column
                    {
                        anchors.verticalCenter: parent.verticalCenter

                        Label
                        {
                            id: mainText
                            font.family: Defines.listViewMainTextFontFamily
                            font.pixelSize: Defines.listViewMainTextFontSize
                            text: model.title
                            font.weight: Font.Bold
                        }
                    }
                }
                Image
                {
                    id: arrowImage
                    source: "qrc:/Images/arrow.png"
                    anchors.right: parent.right;
                    anchors.margins: 25
                    anchors.verticalCenter: parent.verticalCenter
                }

                MouseArea
                {
                    id: mouseArea
                    anchors.fill: background
                    onClicked: openPage(model)
                }
            }
        }
        ScrollDecorator
        {
            flickableItem: listView
        }

        ToolBarLayout
        {
            id: commonTools
            visible: true
            ToolIcon
            {
                id: toolNewExpense
                iconSource: "qrc:/Images/newexpense.png"
                anchors.right: toolNewBudget.left
                onClicked:
                {
                    var page=UCountDB.getPage(UCountDB.PageType.expensesAddEdit)
                    pageStack.push(page)
                }
            }
            ToolIcon
            {
                id: toolNewBudget
                iconSource: "qrc:/Images/newbudget.png"
                anchors.right: toolNewTransfer.left
                onClicked:
                {
                    var pageB=UCountDB.getPage(UCountDB.PageType.budgetsAddEdit)
                    pageStack.push(pageB)
                }
            }
            ToolIcon
            {
                id: toolNewTransfer
                iconSource: "qrc:/Images/newtransfer.png"
                anchors.right: parent.right
                onClicked:
                {
                    var page=UCountDB.getPage(UCountDB.PageType.transfersAddEdit)
                    pageStack.push(page)
                }
            }
        }
        function openPage(model)
        {
            var page=UCountDB.getPage(model.page,false)
            pageStack.push(page)
        }

        function init()
        {
            UCountDB.openDB()
            print("criou mainpage")
        }
        function changedStatus(status)
        {
            if(status!==PageStatus.Active)return
            UCountDB.getDefaultAccount(function(info)
            {
                pageTitle.accountName=info.name
                UCountDB.currentAccountID=info.id
            });
            print("ativou")
        }
        onStatusChanged: changedStatus(status)
        Component.onCompleted:  init()//called first and only once
}
