import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.0
import "ucountDB.js" as UCountDB
import "Defines.js" as Defines

Page
{
    id: preferencesPage
    tools: preferencesTools
    orientationLock: PageOrientation.LockPortrait

    PageTitle
    {
        id: pageTitle
        title: "Preferences"
    }

    ListModel
    {
        id: preferencesModel
        ListElement
        {
            title: "Help"
            page: 18
            image: "qrc:/Images/help.png"
        }
        ListElement
        {
            title: "Password"
            page: 16
            image: "qrc:/Images/password.png"
        }
        ListElement
        {
            title:  "Accounts"
            page: 9
            image: "qrc:/Images/accounts.png"
        }
        ListElement
        {
            title:  "About"
            page: 17
            image: "qrc:/Images/about.png"
        }
    }

    ListView
    {
        id: listView
        anchors.top: pageTitle.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: btnCleanDB.top
        anchors.topMargin: UCountDB.listViewTopMargin
        model: preferencesModel
        clip: true

        delegate:  Item
        {
        id: listItem
        height: Defines.listViewTopItensHeight
        width: parent.width

        BorderImage
        {
            id: background
            anchors.fill: parent
            // Fill page borders
            anchors.leftMargin: -preferencesPage.anchors.leftMargin
            anchors.rightMargin: -preferencesPage.anchors.rightMargin
            visible: mouseArea.pressed
            //source: "qrc:/Images/preferences.png"
        }

        Image
        {
            id: imagem
            source: model.image
            anchors.left: parent.left;
            width: Defines.listViewTopImageSize
            height: Defines.listViewTopImageSize
            anchors.leftMargin: 10
            anchors.verticalCenter: parent.verticalCenter
        }

        Row
        {
            anchors.fill: parent
            anchors.leftMargin: 100
            Column
            {
                anchors.verticalCenter: parent.verticalCenter

                Label
                {
                    id: mainText
                    text: model.title
                    font.weight: Font.Bold
                    font.family: Defines.listViewMainTextFontFamily
                    font.pixelSize: Defines.listViewMainTextFontSize
                }
            }
        }

        Image
        {
            id: arrowImage
            source: "qrc:/Images/arrow.png"
            anchors.right: parent.right;
            anchors.margins: 25
            anchors.verticalCenter: parent.verticalCenter
        }

        MouseArea
        {
            id: mouseArea
            anchors.fill: background
            onClicked: openPage(model)
        }
    }
    }
    Button
    {
        id: btnCleanDB
        text: "Clean Database"
        style: NegativeButtonStyle {}
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 30
        onClicked: queryDialog.open()
    }
    ScrollDecorator
    {
        flickableItem: listView
    }
    QueryDialog
    {
        id: queryDialog
        icon: "qrc:/Images/question.png"
        titleText: "Clean UCount Database"
        message: "Are you sure you want to clean UCount Database?"
        + "All your data will be lost!"
        acceptButtonText: "Yes"
        rejectButtonText: "Cancel"
        onAccepted:
        {
            UCountDB.clearDB()
            pageStack.pop()
        }
    }
    ToolBarLayout
    {
        id: preferencesTools
        visible: true
        ToolIcon
        {
            id: toolBack
            platformIconId: "toolbar-back"
            anchors.left: parent.left
            onClicked: pageStack.pop();
        }
    }
    function openPage(model)
    {
        var page=UCountDB.getPage(model.page,false)
        pageStack.push(page)
    }
}
