import QtQuick 1.1
import com.nokia.meego 1.0
import "ucountDB.js" as UCountDB
import "Defines.js" as Defines

Page
{
    id: passwordPage
    orientationLock: PageOrientation.LockPortrait
    property int secondColumnWidth: 350

    PageTitle
    {
        id: pageTitle
        title: "Password"
        btnDoneVisible: true
        btnCancelVisible: true
        onCancelled:  pageStack.pop()
        onDone: savePassword()
    }

    Grid
    {
        id: grid
        anchors.top: pageTitle.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        anchors.leftMargin: 10
        columns: 2
        spacing: 2        
        anchors.topMargin: UCountDB.gridTopMargin
        Text
        {
            id: lblEnabled
            font.family: Defines.fontFamily
            font.pointSize: Defines.fontSize
            text: qsTr("Enabled")
            anchors.verticalCenter: switchEnabled.verticalCenter
        }
        Switch
        {
            id: switchEnabled
            anchors.right: txtPassword.right
        }
        Text
        {
            id: lblPassword
            font.family: UCountDB.fontFamily
            font.pointSize: UCountDB.fontSize
            text: qsTr("Password")
            anchors.verticalCenter: txtPassword.verticalCenter
        }
        TextField
        {
            id: txtPassword
            width: secondColumnWidth
            echoMode: TextInput.Password
        }
        Text
        {
            id: lblRepeatPassword
            font.family: UCountDB.fontFamily
            font.pointSize: UCountDB.fontSize
            text: qsTr("Repeat Pass")
            anchors.verticalCenter: txtRepeatPassword.verticalCenter
        }
        TextField
        {
            id: txtRepeatPassword
            width: secondColumnWidth
            echoMode: TextInput.Password
        }
    }
    ErrorDialog
    {
        id: errorDialog
    }
    function savePassword()
    {
        if(!switchEnabled.checked)
        {
            UCountDB.disablePassword()
            pageStack.pop()
            return
        }
        if(txtPassword.text.length==0 && txtRepeatPassword.text.length==0)
        {
            errorDialog.text="Password can not be empty"
            errorDialog.open()
            return
        }
        if(txtPassword.text!=txtRepeatPassword.text)
        {
            errorDialog.text="Passwords do not match"
            errorDialog.open()
            return
        }
        var pass=Qt.md5(txtPassword.text)
        UCountDB.savePassword(pass)
        pageStack.pop()
        return
    }
    function init()
    {
        UCountDB.getPassword(function(info)
        {
            switchEnabled.checked=info.passenabled
        });
    }
    Component.onCompleted:  init()
}
