.pragma library
Qt.include("Defines.js")

/**
  *Return the transfers
  */
function readTransfers(accountID, sortType)
{
    var list = {}
    db.readTransaction( function(tx)
    {
        var rs = tx.executeSql("SELECT * FROM transfers where accountfromid= ? ORDER BY dateinserted DESC",accountID);
        var item
        for (var i=0; i< rs.rows.length; i++)
        {
            item = rs.rows.item(i)
            item.transactionType=TransactionType.transfer
            item.value=parseFloat(item.value)
            list[item.id] = item;
        }
    });
    if(sortType===SortType.oneAhead)return getUntilNextYear(list)
    if(sortType===SortType.today)return getOnlyToday(list)
    if(sortType===SortType.lastMonth)return getOnlyLastMonth(list)
    if(sortType===SortType.lastYear)return getOnlyCurrentYear(list)
    if(sortType===SortType.all)return getUntilToday(list)
    return list;
}


/**
  *Return transfers by category
  */
function readTransfersByCategory(accountID,startDate, endDate)
{
    var transactions=new Transactions()
    db.readTransaction( function(tx)
    {
        var rs = tx.executeSql("SELECT * FROM transfers where accountfromid= ? ORDER BY categoryid DESC",accountID);
        var item
        var transaction
        for (var i=0; i< rs.rows.length; i++)
        {
            item = rs.rows.item(i)
            transaction=new Transaction(item.id, parseInt(TransactionType.transfer),item.accountfromid, item.name, item.description, item.dateinserted,parseFloat(item.value),item.categoryid, 0, item.repeat)
            transactions.append(transaction)
        }
    });
    return transactions.getCategoriesList(startDate, endDate)
}


/**
  *Get a transfer specified by transferID
  */
function getTransfer(transferID,callback)
{
    db.transaction( function(tx)
    {
       var resultSet=tx.executeSql("select * from transfers where id = ?",transferID);
       if (resultSet.rows.length > 0)callback(resultSet.rows.item(0))
    });
}


/**
  *Delete the transfer specified by transferID
  */
function deleteTransfer(transferID)
{
    db.transaction( function(tx)
    {
       var expenseFromID=0
       var budgetToID=0
       var savingID=0
       getTransfer(transferID, function(infoTransfer)
       {
            expenseFromID=parseInt(infoTransfer.expensefromid)
            budgetToID=parseInt(infoTransfer.budgettoid)
            savingID=parseInt(infoTransfer.savingid)
        });
        tx.executeSql("DELETE FROM transfers where id = ?",transferID);
        if(budgetToID)tx.executeSql("DELETE FROM budgets where id = ?",budgetToID);
        if(savingID)tx.executeSql("DELETE FROM savings where id = ?",savingID);
        if(expenseFromID)tx.executeSql("DELETE FROM expenses where id = ?",expenseFromID);
    });
}

/**
  *Save a transfer
  */
function saveTransfer(id, accountFromID, accountToID, name, description, dateinserted, value,categoryID, repeatID)
{
    var xID=parseInt(id)
    var xAccountFromID=parseInt(accountFromID)
    var xAccountToID=parseInt(accountToID)
    var xName=name
    var xDescription=description
    var xDateInserted= getStringFromDateToSaveInSqlite(dateinserted)
    var xValue=parseFloat(value).toString()
    var xCategoryID=parseInt(categoryID)
    var xRepeatID=parseInt(repeatID)

    if(xID>0)//update
    {
        db.transaction( function(tx)
        {
           var expenseFromID=0
           var budgetToID=0
           var savingID=0
           getTransfer(id, function(infoTransfer)
           {
                expenseFromID=parseInt(infoTransfer.expensefromid)
                budgetToID=parseInt(infoTransfer.budgettoid)
                savingID=parseInt(infoTransfer.savingid)
            });
            tx.executeSql("update transfers set name= ?, description= ?, dateinserted= ?, accountfromid=?, accounttoid=?, value= ?, categoryid=?, repeat=? where id= ?",
                          [xName,xDescription,xDateInserted,xAccountFromID,xAccountToID, xValue,xCategoryID,xRepeatID, xID]);
            tx.executeSql("update expenses set accountid= ?, name= ?, description= ?, dateinserted= ?, value= ?, categoryid= ?, vendorid= ?,vat= ?, repeat=? where id= ?",
                          [xAccountFromID,xName,xDescription,xDateInserted,xValue,xCategoryID,0,0,xRepeatID, expenseFromID]);
            if(xAccountFromID===xAccountToID)//saving
            {
                tx.executeSql("update savings set accountid=?, name= ?, description= ?, dateinserted= ?, value=?, categoryid=?  where id= ?",
                              [xAccountFromID, xName,xDescription,xDateInserted,xValue,xCategoryID, savingID]);
            }else //to another account
            {
                tx.executeSql("update budgets set accountid=?, name=?, description=?, dateinserted=?, value=?, categoryid=?, repeat=? where id=?",
                              [xAccountToID,xName,xDescription,xDateInserted,xValue,xCategoryID,xRepeatID,budgetToID]);
            }
        });
    }
    else//insert
    {
        db.transaction( function(tx)
        {
            var savingResult=0
            var budgetResult=0
            var expenseResult =tx.executeSql("insert into expenses (accountid, name, description, dateinserted, value, categoryid, vendorid, vat, repeat ) VALUES(?,?,?,?,?,?,?,?,?)",
                        [xAccountFromID,xName,xDescription,xDateInserted,xValue,xCategoryID,0,0,xRepeatID]);
            if(xAccountFromID===xAccountToID)//saving
            {
                savingResult=tx.executeSql("insert into savings ( accountid, name, description, dateinserted, value, categoryid ) VALUES(?,?,?,?,?,?)",
                              [xAccountFromID, xName,xDescription,xDateInserted,xValue,xCategoryID]);
            }else //to another account
            {
                budgetResult=tx.executeSql("insert into budgets (accountid, name, description, dateinserted, value, categoryid, repeat ) VALUES(?,?,?,?,?,?,?)",
                              [xAccountToID,xName,xDescription,xDateInserted,xValue,xCategoryID,xRepeatID]);
            }
            tx.executeSql("insert into transfers (name, description, dateinserted, accountfromid, accounttoid, value, categoryid, expensefromid, budgettoid, savingid, repeat ) VALUES(?,?,?,?,?,?,?,?,?,?,?)",
                          [xName,xDescription,xDateInserted,xAccountFromID,xAccountToID, xValue,xCategoryID,
                           parseInt(expenseResult.insertId), parseInt(budgetResult.insertId),parseInt(savingResult.insertId), xRepeatID]);
        });
    }
}
