import QtQuick 1.1
import com.nokia.meego 1.0
import "ucountDB.js" as UCountDB
import "Defines.js" as Defines

Item
{
    anchors.fill: parent
    property alias pageInfo : pageTitle
    property alias title : pageTitle.title
    property variant pressedAndHoldItem : null
    property alias listModel: ucountModel
    signal listItemClicked(int id, int transactionType)
    signal listItemPressAndHold(int id, int transactionType)

    PageTitle
    {
        id: pageTitle
        title: ""
    }
    ListModel
    {
        id: ucountModel
        ListElement
        {
            title: ""
            dateInserted: ""
            value: 0
            subtitle: ""
            image: ""
            tableID: 0
            category: ""
            showDate:false
            transactionColor: "black"
            transactionType: 0
        }
    }
    ListView
    {
            id: listView
            anchors.top: pageTitle.bottom
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.bottom: parent.bottom
            anchors.topMargin: 0
            model: ucountModel
            clip: true

            delegate:  Item
            {
                id: listItem
                height: Defines.listViewItensHeight
                width: parent.width
                property variant itemData: model

                BorderImage
                {
                    id: background
                    anchors.fill: parent
                    anchors.leftMargin: -parent.anchors.leftMargin
                    anchors.rightMargin: -parent.anchors.rightMargin
                    visible: mouseArea.pressed
                }
                Image
                {
                    id: imagem
                    source: model.image
                    anchors.left: parent.left;
                    width: Defines.listViewItensImageSize
                    height: Defines.listViewItensImageSize
                    anchors.leftMargin: Defines.listViewLeftMargin
                    anchors.verticalCenter: row.verticalCenter
                }

                Row
                {
                    id: row
                    anchors.fill:  parent
                    anchors.leftMargin: 100
                    Column
                    {
                        anchors.verticalCenter: parent.verticalCenter

                        Label
                        {
                            id: mainText
                            text: model.title
                            font.weight: Font.Bold
                            font.family: Defines.listViewItensMainTextFontFamily
                            font.pixelSize: Defines.listViewItensMainTextFontSize
                        }

                        Label
                        {
                            id: subText
                            text: model.subtitle
                            font.family: Defines.listViewItensSubTextFontFamily
                            font.pixelSize: Defines.listViewItensSubTextFontSize
                            color: Defines.listViewItensSubTextFontColor
                            visible: text != ""
                        }
                    }
                }
                Label
                {
                    id: lblCategory
                    text: model.category
                    font.family: Defines.listViewItensCategoryFontFamily
                    font.pixelSize: Defines.listViewItensCategoryFontSize
                    color: Defines.listViewItensCategoryFontColor
                    anchors.verticalCenter: row.verticalCenter
                    anchors.right: valueText.left
                    anchors.rightMargin: Defines.listViewRightMargin
                }
                Label
                {
                    id: valueText
                    text: model.value
                    font.weight: Font.Bold
                    font.family: Defines.valueFontFamily
                    font.pixelSize: Defines.valueFontSize
                    anchors.right: parent.right
                    anchors.rightMargin: Defines.listViewRightMargin
                    anchors.verticalCenter: row.verticalCenter
                    color: model.transactionColor
                    visible: model.value?true:false
                }

                MouseArea
                {
                    id: mouseArea
                    anchors.fill: background
                    onClicked: listItemClicked(model.tableID,model.transactionType)
                    onPressAndHold: listItemPressAndHold(model.tableID, model.transactionType)
                }
            }
            section.property: "dateInserted"
            section.criteria: ViewSection.FullString
            section.delegate: Item
            {
                // "GroupHeader" component?
                width: parent.width
                height: 40
                Text
                {
                    id: headerLabel
                    anchors.right: parent.right
                    anchors.bottom: parent.bottom
                    anchors.rightMargin: 50
                    anchors.bottomMargin: 2
                    text: section
                    font.bold: true
                    font.pointSize: 18
                    color: theme.inverted ? "#4D4D4D" : "#3C3C3C";
                }
                Image
                {
                    anchors.right: headerLabel.left
                    anchors.left: parent.left
                    anchors.verticalCenter: headerLabel.verticalCenter
                    anchors.rightMargin: 24
                    source: "image://theme/meegotouch-groupheader" + (theme.inverted ? "-inverted" : "") + "-background"
                }
            }
        }
        ScrollDecorator
        {
            flickableItem: listView            
        }
        SectionScroller
        {
            listView: listView
        }
}
