.pragma library
Qt.include("Expenses.js")
Qt.include("Defines.js")
Qt.include("Budgets.js")
Qt.include("Transfers.js")
Qt.include("Categories.js")
Qt.include("Vendors.js")
Qt.include("Accounts.js")
Qt.include("Icons.js")
Qt.include("Savings.js")
Qt.include("Preferences.js")
Qt.include("Histories.js")

function openDB()
{
    if(!db)
    {
        db = openDatabaseSync("UCountDB","1.0","UCount Database",1000000);
        createUCountTables();
    }
}


/**
  *
  */
function createUCountTables()
{
    db.transaction( function(tx)
    {
       var rs = tx.executeSql("SELECT name FROM sqlite_master WHERE type='table' AND name='expenses'");
       if(rs.rows.length>0)return
        tx.executeSql("CREATE TABLE IF NOT EXISTS expenses ( \
                            id INTEGER PRIMARY KEY AUTOINCREMENT, \
                            accountid integer not null, \
                            name text not null, \
                            description text, \
                            dateinserted text not null, \
                            value text not null, \
                            categoryid integer, \
                            vendorid integer, \
                            vat text, \
                            repeat integer not null)");

       tx.executeSql("create table if not exists accounts ( \
                           id INTEGER PRIMARY KEY AUTOINCREMENT, \
                           name text not null, \
                           description text, \
                           defaultaccount integer, \
                           iconid integer)");

       tx.executeSql("create table if not exists budgets ( \
                           id INTEGER PRIMARY KEY AUTOINCREMENT, \
                           accountid integer not null, \
                           name text not null, \
                           description text, \
                           dateinserted text not null, \
                           value text not null, \
                           categoryid integer, \
                           repeat integer not null)");

       tx.executeSql("create table if not exists savings ( \
                           id INTEGER PRIMARY KEY AUTOINCREMENT, \
                           accountid integer not null, \
                           name text not null, \
                           description text, \
                           dateinserted text not null, \
                           value text not null, \
                           categoryid integer)");

       tx.executeSql("create table if not exists categories ( \
                           id INTEGER PRIMARY KEY AUTOINCREMENT, \
                           parentid integer, \
                           name text not null, \
                           description text, \
                           iconid integer)");

       tx.executeSql("create table if not exists icons ( \
                           id INTEGER PRIMARY KEY AUTOINCREMENT, \
                           name text not null, \
                           qrcpath text not null)");

       tx.executeSql("create table if not exists preferences ( \
                           id INTEGER PRIMARY KEY AUTOINCREMENT, \
                           version text not null, \
                           password text, \
                           passenabled integer)");

       tx.executeSql("create table if not exists transfers ( \
                           id INTEGER PRIMARY KEY AUTOINCREMENT, \
                           name text not null, \
                           description text, \
                           dateinserted text not null, \
                           accountfromid integer not null, \
                           accounttoid integer not null, \
                           value text not null, \
                           categoryid integer, \
                           expensefromid integer, \
                           budgettoid integer, \
                           savingid integer, \
                           repeat integer not null)");

       tx.executeSql("create table if not exists vendors ( \
                           id INTEGER PRIMARY KEY AUTOINCREMENT, \
                           name text not null, \
                           description text, \
                           categoryid integer not null)");
       fillDB()
    });
}


/**
  *Return the page specified by page.
  *If it was not created, its created now
  */
function getPage(page,destroyOld)
{
    switch(page)
    {
        case PageType.preferences:
            if(destroyOld && pref)pref.destroy()
            if(!pref)pref = Qt.createComponent("Preferences.qml");
            return pref
        case PageType.expensesAddEdit:
            if(!accountExpenseAddEdit)accountExpenseAddEdit = Qt.createComponent("AccountExpensesAddEdit.qml");
            return accountExpenseAddEdit
        case PageType.budgets:
            if(destroyOld && accountBudgets)accountBudgets.destroy()
            if(!accountBudgets)accountBudgets = Qt.createComponent("AccountBudgets.qml");
            return accountBudgets
        case PageType.budgetsAddEdit:
            if(!accountBudgetAddEdit)accountBudgetAddEdit= Qt.createComponent("AccountBudgetsAddEdit.qml");
            return accountBudgetAddEdit
        case PageType.transfersAddEdit:
            if(!accountTransferAddEdit)accountTransferAddEdit=Qt.createComponent("AccountTransferAddEdit.qml");
            return accountTransferAddEdit
        case PageType.vendorsAddEdit:
            if(!accountVendorAddEdit)accountVendorAddEdit=Qt.createComponent("AccountVendorsAddEdit.qml");
            return accountVendorAddEdit
        case PageType.vendors:
            if(destroyOld && accountVendors)accountVendors.destroy()
            if(!accountVendors)accountVendors = Qt.createComponent("AccountVendors.qml");
            return accountVendors
        case PageType.accounts:
            if(destroyOld && preferencesAccounts)preferencesAccounts.destroy()
            if(!preferencesAccounts)preferencesAccounts = Qt.createComponent("PreferencesAccounts.qml");
            return preferencesAccounts
        case PageType.preferencesPassword:
            if(destroyOld && preferencesPassword)preferencesPassword.destroy()
            if(!preferencesPassword)preferencesPassword = Qt.createComponent("PreferencesPassword.qml");
            return preferencesPassword
        case PageType.preferencesAbout:
            if(destroyOld && preferencesAbout)preferencesAbout.destroy()
            if(!preferencesAbout)preferencesAbout = Qt.createComponent("PreferencesAbout.qml");
            return preferencesAbout
        case PageType.preferencesHelp:
            if(destroyOld && preferencesHelp)preferencesHelp.destroy()
            if(!preferencesHelp)preferencesHelp = Qt.createComponent("PreferencesHelp.qml");
            return preferencesHelp
        case PageType.accountsAddEdit:
            if(!accountAddEdit)accountAddEdit=Qt.createComponent("PreferencesAccountAddEdit.qml");
            return accountAddEdit
        case PageType.categories:
            if(destroyOld && accountCategories)accountCategories.destroy()
            if(!accountCategories)accountCategories = Qt.createComponent("AccountCategories.qml");
            return accountCategories
        case PageType.categoriesAddEdit:
            if(!accountCategoriesAddEdit)accountCategoriesAddEdit=Qt.createComponent("AccountCategoriesAddEdit.qml");
            return accountCategoriesAddEdit
        case PageType.expenses:
            if(destroyOld && accountExpenses)accountExpenses.destroy()
            if(!accountExpenses)accountExpenses = Qt.createComponent("AccountExpenses.qml");
            return accountExpenses
        case PageType.transfers:
            if(destroyOld && accountTransfers)accountTransfers.destroy()
            if(!accountTransfers)accountTransfers = Qt.createComponent("AccountTransfers.qml");
            return accountTransfers
        case PageType.history:
            if(destroyOld && accountHistory)accountHistory.destroy()
            if(!accountHistory)accountHistory = Qt.createComponent("AccountHistory.qml");
            return accountHistory
        case PageType.reports:
            if(destroyOld && accountReports)accountReports.destroy()
            if(!accountReports)accountReports = Qt.createComponent("AccountReports.qml");
            return accountReports
        case PageType.savings:
            if(destroyOld && accountSavings)accountSavings.destroy()
            if(!accountSavings)accountSavings = Qt.createComponent("AccountSavings.qml");
            return  accountSavings
        case PageType.savingsAddEdit:
            if(destroyOld && accountSavingsAddEdit)accountSavingsAddEdit.destroy()
            if(!accountSavingsAddEdit)accountSavingsAddEdit = Qt.createComponent("AccountSavingsAddEdit.qml");
            return accountSavingsAddEdit
        case PageType.reportsResult:
            if(destroyOld && accountReportsResult)accountReportsResult.destroy()
            if(!accountReportsResult)accountReportsResult = Qt.createComponent("AccountReportsResult.qml");
            return accountReportsResult

    }
}


/**
  *
  */
function getRepeatName(repeatID)
{
    switch(repeatID)
    {
        case RepeatType.once:
            return "Once"
        case RepeatType.everyday:
            return "Every day"
        case RepeatType.everyweek:
            return "Every week"
        case RepeatType.everymonth:
            return "Every month"
        case RepeatType.everyyear:
            return "Every year"
    }
}


/**
  *
  */
function clearDB()
{
    db.transaction( function(tx)
    {
        tx.executeSql("DELETE FROM accounts");
        tx.executeSql("DELETE FROM budgets");
        tx.executeSql("DELETE FROM categories");
        tx.executeSql("DELETE FROM expenses");
        tx.executeSql("DELETE FROM icons");
        tx.executeSql("DELETE FROM preferences");
        tx.executeSql("DELETE FROM savings");
        tx.executeSql("DELETE FROM transfers");
        tx.executeSql("DELETE FROM vendors");
        fillDB()
    });
}


/**
  *
  */
function fillDB()
{
    db.transaction( function(tx)
    {
        tx.executeSql("insert or replace into accounts(name,description,defaultaccount) values (?,?,?)",["MainAccount","First account",1]);
        tx.executeSql("insert into icons values (?,?,?)",[1,"Cake","cake.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[2,"Shopping cart","shoppingcart.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[3,"House","house.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[4,"Car","car.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[5,"Unknown","unknown.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[6,"Fun","fun.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[7,"Donut","donut.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[8,"Monitor","monitor.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[9,"Printer","printer.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[10,"Meal","meal.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[11,"Beer","beer.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[12,"Computer","computer.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[13,"Book","book.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[14,"Movie","movie.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[15,"Wine","wine.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[16,"Package","package.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[17,"Trash","trash.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[18,"People","people.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[19,"Game","game.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[20,"Light","light.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[21,"Tools","tools.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[22,"Music","music.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[23,"Security","security.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[24,"Man","man.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[25,"Smile","smile.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[26,"Bomb","bomb.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[27,"Star","star.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[28,"Toy","toy.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[29,"Vacations","vacations.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[30,"Fruit","fruit.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[31,"Energy","energy.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[32,"Phone","phone.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[33,"Jewel","jewel.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[34,"Love","love.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[35,"Internet","internet.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[36,"Document","document.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[37,"Construction","construction.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[38,"Coffee","coffee.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[39,"Dog","dog.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[40,"Cat","cat.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[41,"Furniture","furniture.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[42,"School","school.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[43,"Plane","plane.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[44,"Bus","bus.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[45,"Beatle","beatle.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[46,"Hotel","hotel.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[47,"Beach","beach.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[48,"Woman","woman.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[49,"Gift","gift.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[50,"Credit card","creditcard.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[51,"Sale","sale.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[52,"Painting","painting.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[53,"Car mechanic","carmechanic.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[54,"Gas","gas.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[55,"Money","money.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[56,"Health","health.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[57,"Gym","gym.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[58,"Doctor","doctor.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[59,"Receipt","receipt.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[60,"Taxi","taxi.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[61,"Motorcycle","motorcycle.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[62,"TShirt","shirt.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[63,"Bag","bag.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[64,"Baby","baby.png"]);
        tx.executeSql("insert into icons values (?,?,?)",[65,"Hairdresser","hairdresser.png"]);

       tx.executeSql("insert into categories values (?,?,?,?,?)",[1,0,"Food","All food related",1]);
       tx.executeSql("insert into categories values (?,?,?,?,?)",[2,0,"Car","All car related",4]);
       tx.executeSql("insert into categories values (?,?,?,?,?)",[3,0,"House","All house related",3]);
       tx.executeSql("insert into categories values (?,?,?,?,?)",[4,0,"Fun","All fun related",6]);
       tx.executeSql("insert into categories values (?,?,?,?,?)",[5,0,"Others","All others related",5]);

       tx.executeSql("insert into preferences values (?,?,?,?)",[1,"1.0.0","",0]);
    });
}
